/*
** Module   : LabeledDataContainer.java
** Abstract : P2JComponent with optional side or top label.
**
** Copyright (c) 2010-2011, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ----------------Description-----------------
** 001 SIY 20100820          Refactored common code from Editor and FillIn.
** 002 SIY 20100915          Renamed class and base class from 
**                           LabeledP2JComponent.
** 003 SIY 20111101          Moved from CHUI package. Minor 
**                           cleanups/refactorings in preparation to GUI client.
** 004 SIY 20111202          Updated imports.
** 005 EVL 20140528          Fix for displaying the labels for hidden widgets in a frame.  We
**                           need to keep track when the widget become visible to differentiate
**                           the hidden widgets rendering.
*/

package com.goldencode.p2j.ui.client;

import com.goldencode.p2j.ui.*;

/**
 * Common implementation of {@link LabeledWidget} interface for 
 * {@link FillIn} and {@link Editor}.
 * 
 * @author  SIY
 * @version 1.0
 */
public abstract class LabeledDataContainer
extends FixedSizeContainer
implements LabeledWidget,
           DataContainer
{
   /** Component label. */
   private Label sideLabel = null;
   
   /** Flag indicating the widget was made visible at least once. */
   private boolean wasVisible = false;
   
   /**
    * Provide access to the attributes stored in the widget.
    * 
    * @return  Reference to attribute container.
    */
   @SuppressWarnings("unchecked")
   @Override
   public ControlTextConfig config()
   {
      return null;
   }
   
   /**
    * Return current value of COLON attribute.
    * 
    * @return  Current value of the attribute.
    */
   @Override
   public int getColon()
   {
      return config().getColon();
   }

   /**
    * Return text of the column label.
    * 
    * @return  text of the column label.
    */
   @Override
   public String getColumnLabelText()
   {
      return config().getColumnLabel();
   }

   /**
    * Return reference to the instance of the <code>Label</code> attached to
    * the widget.
    * 
    * @return  Reference to <code>Label</code> instance.
    */
   @Override
   public Label getLabelInstance()
   {
      return sideLabel;
   }

   /**
    * Return text of the label.
    * 
    * @return  text of the label.
    */
   @Override
   public String getLabelText()
   {
      return config().getLabel();
   }

   /**
    * Return current value of TO attribute.
    * 
    * @return  Current value of the attribute.
    */
   @Override
   public int getTo()
   {
      return config().getTo();
   }

   /**
    * Check if widget has fixed column position.
    * 
    * @return  <code>true</code> if widget column is fixed.
    */
   @Override
   public boolean isColumnFixed()
   {
      return config().getAssignedColumn() != BaseConfig.INV_COORD;
   }
   
   /**
    * Get current state of flag which is forces presence of the label
    * regardless from the frame NO-LABELS option.
    * 
    * @return  Current state of the flag.
    */
   @Override
   public boolean isForceLabel()
   {
      return config().isForceLabel();
   }
   
   /**
    * Get current state of NO-LABELS flag.
    * 
    * @return  Current state of the flag.
    */
   @Override
   public boolean isNoLabels()
   {
      return config().isNoLabels();
   }

   /**
    * Get widget alignment policy.
    * 
    * @return  <code>true</code> if widget is formatted for right alignment.
    */
   @Override
   public boolean isRightAligned()
   {
      return false;
   }

   /**
    * Set new value for the COLON attribute.
    * 
    * @param   colon
    *          New value for the attribute.
    */
   @Override
   public void setColon(int colon)
   {
      config().setColon(colon);
   }

   /**
    * Assign new instance of <code>Label</code> to the fill-in widget.
    * 
    * @param   label
    *          Reference to new <code>Label</code> instance.
    */
   @Override
   public void setLabelInstance(Label label)
   {
      sideLabel = label;
      
      if (sideLabel.isVisible() != isVisible())
         sideLabel.setVisible(isVisible());
   }
   
   /**
    * Force NO-LABELS flag.
    *
    * @param   labels
    *          New value of the flag.
    */
   @Override
   public void setNoLabels(boolean labels)
   {
      config().setNoLabels(labels);
   }

   /**
    * Set new value for the TO attribute.
    * 
    * @param   pos
    *          New value for the attribute.
    */
   @Override
   public void setTo(int pos)
   {
      config().setTo(pos);
   }
   
   /**
    * Shows or hides the widget and attached label.
    *
    * @param    visible
    *           <code>true</code> to make the widget visible, 
    *           <code>false</code> to hide the widget.
    */
   @Override
   public void setVisible(boolean visible)
   {
      super.setVisible(visible);

      if (sideLabel != null)
         sideLabel.setVisible(visible);
   }

   /**
    * Getting the modification state of the widget.
    * 
    * @return  <code>true</code> if the widget value was modified,
    *          <code>false</code> otherwise.
    */
   @Override
   public boolean isModified()
   {
      return config().isModified();
   }
   
   /**
    * Checking if the widget was made visible at least once.
    * 
    * @return  <code>true</code> if the widget was visible,
    *          <code>false</code> otherwise.
    */
   @Override
   public boolean wasVisible()
   {
      return wasVisible;
   }
   
   /**
    * Remember the widget was made visible at least once.
    */
   @Override
   public void wasVisibleOn()
   {
      wasVisible = true;
   }
}
