/*
** Module   : LabeledWidget.java
** Abstract : Common interface for widgets which can have label (top or side).
**
** Copyright (c) 2006-2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ----------------Description-----------------
** 001 SIY 20060209  @24456  Created initial version
** 002 SIY 20060322  @25224  Added setNoLabels() method.
** 003 SIY 20060515  @26154  Added getColumnLabelText().
** 004 SIY 20070807  @34816  Added isColumnFixed() method.
** 005 SIY 20111101          Moved from CHUI package. Minor 
**                           cleanups/refactorings in preparation to GUI client.
** 006 SIY 20111202          Updated imports.
** 007 EVL 20140528          Fix for displaying the labels for hidden widgets in a frame.  We
**                           need to keep track when the widget become visible to differentiate
**                           the hidden widgets rendering.
*/

package com.goldencode.p2j.ui.client;

/**
 * Interface which describes widgets which can have top or side labels. 
 * Actual labels are assigned by the active layout manager according to
 * common frame and individual widget settings. 
 * 
 * @author  SIY
 * @version 1.0
 */
public interface LabeledWidget
{
   /**
    * Return reference to the instance of the <code>Label</code> attached to
    * the widget.
    * 
    * @return  Reference to <code>Label</code> instance.
    */
   public Label getLabelInstance();
   
   /**
    * Assign new instance of <code>Label</code> to the widget.
    * 
    * @param   label
    *          Reference to new <code>Label</code> instance.
    */
   public void setLabelInstance(Label label);
   
   /**
    * Return text of the label.
    * 
    * @return  text of the label.
    */
   public String getLabelText();

   /**
    * Return text of the column label.
    * 
    * @return  text of the column label.
    */
   public String getColumnLabelText();
   
   /**
    * Return TO column.
    * 
    * @return  Column assigned via TO option.
    */
   public int getTo();

   /**
    * Get current state of flag which is forces presence of the label
    * regardless from the frame NO-LABELS option.
    * 
    * @return  Current state of the flag.
    */
   public boolean isForceLabel();

   /**
    * Get current state of NO-LABELS flag.
    * 
    * @return  Current state of the flag.
    */
   public boolean isNoLabels();

   /**
    * Assign new TO column.
    * 
    * @param   col
    *          New value for the option.
    */
   public void setTo(int col);

   /**
    * Return current value of COLON option.
    * 
    * @return  Current value of the option column.
    */
   public int getColon();

   /**
    * Set new value for the COLON option.
    * 
    * @param   colon
    *          New value for the option column.
    */
   public void setColon(int colon);

   /**
    * Get widget alignment policy.
    * 
    * @return  <code>true</code> if widget is formatted for right alignment.
    */
   public boolean isRightAligned();

   /**
    * Force NO-LABELS flag.
    * 
    * @param   labels
    *          New value of the flag.
    */
   public void setNoLabels(boolean labels);
   
   /**
    * Check if widget has fixed column position.
    * 
    * @return  <code>true</code> if widget column is fixed.
    */
   public boolean isColumnFixed();
   
   /**
    * Get current hidden state.
    * 
    * @return   hidden state.
    */
   public boolean hidden();

   /**
    * Checking if the widget was made visible at least once.
    * 
    * @return  <code>true</code> if the widget was visible,
    *          <code>false</code> otherwise.
    */
   public boolean wasVisible();
   
   /**
    * Remember the widget was made visible at least once.
    */
   public void wasVisibleOn();
}
